@@ -9,6 +9,9 @@
     (at your option) any later version.  See <http://www.gnu.org/licenses/>.
 */
 
+#include <stdlib.h>
+
+#include <flint/fmpq.h>
 #include <flint/fmpq_vec.h>
 
 #include "../../e-antic/fmpz_poly_extra.h"
