@@ -9,6 +9,9 @@
     (at your option) any later version.  See <http://www.gnu.org/licenses/>.
 */
 
+#include <math.h>
+#include <stdlib.h>
+
 #include "../../e-antic/renf.h"
 #include "../../e-antic/fmpz_poly_extra.h"
 #include "../../e-antic/fmpq_poly_extra.h"
@@ -23,7 +26,7 @@ static void check_renf(renf_t nf)
     if (fmpq_poly_length(nf->nf->pol) != fmpz_poly_length(nf->der) + 1)
     {
         printf("FAIL:\n");
-        printf("uninitalized derivative");
+        printf("uninitialized derivative");
         fflush(stdout);
         abort();
     }
