@@ -9,6 +9,11 @@
     (at your option) any later version.  See <http://www.gnu.org/licenses/>.
 */
 
+#include <math.h>
+#include <stdlib.h>
+
+#include <flint/fmpz_vec.h>
+
 #include "../../e-antic/renf.h"
 #include "../../e-antic/fmpz_poly_extra.h"
 
