@@ -9,6 +9,10 @@
     (at your option) any later version.  See <http://www.gnu.org/licenses/>.
 */
 
+#include <stdlib.h>
+
+#include <flint/fmpz_vec.h>
+
 #include "../../e-antic/renf_elem.h"
 
 static int sgn(int a) {
